from .xcolor import *

__all__ = [
    "Color",
    "color",
    "BLACK",
    "RED",
    "GREEN",
    "YELLOW",
    "BLUE",
    "PURPLE",
    "CYAN",
    "WHITE",
    "IBLACK",
    "IRED",
    "IGREEN",
    "IYELLOW",
    "IBLUE",
    "IPURPLE",
    "ICYAN",
    "IWHITE",
    "UBLACK",
    "URED",
    "UGREEN",
    "UYELLOW",
    "UBLUE",
    "UPURPLE",
    "UCYAN",
    "UWHITE",
    "TBLACK",
    "TRED",
    "TGREEN",
    "TYELLOW",
    "TBLUE",
    "TPURPLE",
    "TCYAN",
    "TWHITE",
    "test_color",
    "test_style",
]
